<?php
namespace Anymag_Framework\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Anymag_Blog extends Widget_Base {

	public function get_name() {
		return 'anymag_blog';
	}

	public function get_title() {
		return __( 'Anymag Blog', 'anymag-core' );
	}

	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	public function get_categories() {
		return [ 'anymagtheme' ];
	}

	public function get_script_depends() {
		return [ 'script-elementor' ];
	}

	protected function _register_controls() {
    
    $args='';

		$categories=get_categories($args);
		$cate_array = array();
		$arrayCateAll = array( 'all' => 'All categories ' );
		if ($categories) {
			foreach ( $categories as $cate ) {
				$cate_array[$cate->cat_name] = $cate->slug;
			}
		} else {
			$cate_array["No content Category found"] = 0;
		}

		//SECTION CONTENT
		$this->start_controls_section(
			'section_recent_posts',
			[
				'label' => esc_html__( 'Anymag Recent Posts', 'anymag-core' ),
			]
		);
		$this->add_control(
			'block_title',
			[
				'label' => esc_html__( 'Block title', 'anymag-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);
		$this->add_control(
			'post_style',
			[
				'label' => esc_html__( 'Post Style', 'anymag-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'post-list' => esc_html__( 'List', 'anymag-core' ),
					'post-grid' => esc_html__( 'Grid', 'anymag-core' ),
					'post-wide' => esc_html__( 'Wide', 'anymag-core' ),
				],
				'default' => 'post-list',
			]
		);
		$this->add_control(
			'overlay',
			[
				'label' => __( 'Overlay', 'anymag-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'anymag-core' ),
				'label_off' => __( 'Hide', 'anymag-core' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_control(
			'num',
			[
				'label' => esc_html__( 'Posts Count', 'anymag-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => '6',
			]
		);
		$this->add_control(
			'category',
			[
				'label' => __( 'Category', 'anymag-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'all',
				'options' => array_merge($arrayCateAll,$cate_array),
			]
		);
		$this->add_control(
			'orderby',
			[
				'label' => esc_html__( 'Order by', 'anymag-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'date' => esc_html__( 'Date', 'anymag-core' ),
					'random' => esc_html__( 'Random', 'anymag-core' ),
				],
				'default' => 'date',
			]
		);
		$this->add_control(
			'show_cats',
			[
				'label' => __( 'Show Category', 'anymag-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'anymag-core' ),
				'label_off' => __( 'Hide', 'anymag-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_excerpt',
			[
				'label' => __( 'Show Excerpt', 'anymag-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'anymag-core' ),
				'label_off' => __( 'Hide', 'anymag-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_author',
			[
				'label' => __( 'Show Author', 'anymag-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'anymag-core' ),
				'label_off' => __( 'Hide', 'anymag-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_avatar',
			[
				'label' => __( 'Show Author Avatar', 'anymag-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'anymag-core' ),
				'label_off' => __( 'Hide', 'anymag-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_date',
			[
				'label' => __( 'Show Date', 'anymag-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'anymag-core' ),
				'label_off' => __( 'Hide', 'anymag-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$this->add_control(
			'pagination',
			[
				'label' => esc_html__( 'Pagination', 'anymag-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'loadmore' => esc_html__( 'Load more', 'anymag-core' ),
					'classic' => esc_html__( 'Classic', 'anymag-core' ),
					'infinite' => esc_html__( 'Infinite scroll', 'anymag-core' ),
				],
				'default' => 'loadmore',
			]
		);
		$this->add_control(
			'exclude_posts',
			[
				'label' => __( 'Exclude Posts', 'anymag-core' ),
				'type' => Controls_Manager::SELECT2,
				'options' => anymag_all_posts(),
				'default' => '',
				'multiple' => true
			]
		);
		if (get_theme_mod( 'anymag_multiple_issues' )) {
		$this->add_control(
			'blog_tag',
			[
				'label' => esc_html__( 'Tag', 'anymag-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);
	  }

		$this->end_controls_section();
		//END SECTION CONTENT
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		extract(shortcode_atts(array(
	    'block_title' => '',
	    'post_style' => 'post-list',
    	'num' => '',
    	'orderby' => 'date',
    	'order' => 'DESC',
    	'cat_slug' => '',
    	'category' => '',
    	'overlay' => '',
     	'show_cats' => 'true',
    	'show_author' => 'true',
    	'show_avatar' => 'true',
    	'show_date' => 'true',
    	'show_excerpt' => 'true',
    	'pagination' => 'loadmore',
    	'ignore_sticky_posts' => 'false',
    	'exclude_posts' => '',
    	'blog_tag' => '',
	    ), $settings));

		$exclude_posts = $exclude_posts != '' ? $exclude_posts : array();
		$exclude_posts = implode(',', $exclude_posts);

		
 		if ($category != 'all') {
		  $category = get_term_by( 'name', $category, 'category');
      $category = $category->slug;
    }

    $out = '[show_posts
			title="'.$block_title.'" 
			num="'.$num.'" 
			post_style="'.$post_style.'" 
			overlay="'.$overlay.'" 
			category="'.$category.'" 
			order="'.$orderby.'" 
			show_cats="'.$show_cats.'" 
			pagination="'.$pagination.'" 
			show_author="'.$show_author.'" 
			show_avatar="'.$show_avatar.'" 
			show_date="'.$show_date.'" 
			show_excerpt="'.$show_excerpt.'" 
			exclude_posts="'.$exclude_posts.'" 
			tag="'.$blog_tag.'" 
			ignore_sticky_posts="'.$ignore_sticky_posts.'"]';
		echo shortcode_unautop(do_shortcode($out));
	}
}
