<?php
namespace Anymag_Framework\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Anymag_Featcat extends Widget_Base {

	public function get_name() {
		return 'anymag_featcat';
	}

	public function get_title() {
		return __( 'Anymag Featured Category', 'anymag-core' );
	}

	public function get_icon() {
		return 'eicon-gallery-group';
	}

	public function get_categories() {
		return [ 'anymagtheme' ];
	}

	public function get_script_depends() {
		return [ 'script-elementor' ];
	}

	protected function _register_controls() {

    $args = '';
		
		$categories=get_categories($args);
		$cate_array = array();
		$arrayCateAll = array( 'all' => 'All categories ' );
		if ($categories) {
			foreach ( $categories as $cate ) {
				$cate_array[$cate->cat_name] = $cate->slug;
			}
		} else {
			$cate_array["No content Category found"] = 0;
		}

		//SECTION CONTENT
		$this->start_controls_section(
			'section_recent_posts',
			[
				'label' => esc_html__( 'Anymag Featured Category', 'anymag-core' ),
			]
		);
		$this->add_control(
			'block_title',
			[
				'label' => esc_html__( 'Block title', 'anymag-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);
		$this->add_control(
			'category',
			[
				'label' => __( 'Category', 'anymag-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'all',
				'options' => array_merge($arrayCateAll,$cate_array),
			]
		);
		$this->add_control(
			'post_ids',
			[
				'label' => __( 'Select Posts', 'anymag-core' ),
				'type' => Controls_Manager::SELECT2,
				'options' => anymag_all_posts(),
				'default' => '',
				'multiple' => true
			]
		);
		$this->add_control(
			'show_author',
			[
				'label' => __( 'Show Author', 'anymag-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'anymag-core' ),
				'label_off' => __( 'Hide', 'anymag-core' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_control(
			'show_avatar',
			[
				'label' => __( 'Show Author Avatar', 'anymag-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'anymag-core' ),
				'label_off' => __( 'Hide', 'anymag-core' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_control(
			'show_date',
			[
				'label' => __( 'Show Date', 'anymag-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'anymag-core' ),
				'label_off' => __( 'Hide', 'anymag-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		if (get_theme_mod( 'anymag_multiple_issues' )) {
		$this->add_control(
			'cat_tag',
			[
				'label' => esc_html__( 'Tag', 'anymag-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);
	  }
		$this->end_controls_section();
		//END SECTION CONTENT
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		extract(shortcode_atts(array(
	    'block_title' => '',
    	'orderby' => 'date',
    	'order' => 'DESC',
    	'category' => '',
    	'post_ids' => '',
    	'show_author' => 'false',
    	'show_avatar' => 'false',
    	'show_date' => 'true',
    	'cat_tag' => '',
    	'ignore_sticky_posts' => 'false'
	    ), $settings));

		$post_ids = $post_ids != '' ? $post_ids : array();
		$post_ids = implode(',', $post_ids);
    
    if ($category != 'all') {
      $category = get_term_by( 'name', $category, 'category');
      $category = $category->slug;
    }

    $out = '[feat_category
			title="'.$block_title.'" 
			category="'.$category.'" 
			show_author="'.$show_author.'" 
			show_avatar="'.$show_avatar.'" 
			show_date="'.$show_date.'" 
			post_ids="'.$post_ids.'"
		  tag="'.$cat_tag.'"]';
		
		echo shortcode_unautop(do_shortcode($out));

	}
}
