<?php

namespace Anymag_Framework\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Anymag_Products extends Widget_Base {

  public function get_name() {
    return 'anymag_products';
  }

  public function get_title() {
    return esc_html__( 'Anymag Products', 'anymag-core' );
  }

  public function get_icon() {
    return 'eicon-cart-medium';
  }

  public function get_categories() {
    return [ 'anymagtheme' ];
  }

  public function get_script_depends() {
    return [ 'script-elementor' ];
  }

  protected function _register_controls() {

      
    //SECTION CONTENT
    $this->start_controls_section(
      'content_section',
      [
        'label' => esc_html__( 'Content', 'anymag-core' ),
        'tab' => Controls_Manager::TAB_CONTENT,
      ]
    );
      
      $this->add_control(
        'block_title', 
        [
          'label' => esc_html__( 'Widget Title', 'anymag-core' ),
          'type' => Controls_Manager::TEXT
        ]
      );

      $this->add_control(
        'product_type',
        [
          'label' => esc_html__( 'Get Products By', 'anymag-core' ),
          'type' => Controls_Manager::SELECT,
          'options' => array(
              'recent_product' => esc_html__('Recent Products', 'anymag-core' ),
              'best_selling' => esc_html__('Best Selling', 'anymag-core' ),
              'featured_product' => esc_html__('Featured Products', 'anymag-core' ),
              'top_rate' => esc_html__('Top Rate', 'anymag-core' ),
              'on_sale' => esc_html__('On Sale', 'anymag-core' ),
              'recent_review' => esc_html__('Recent Review', 'anymag-core' ),
          ),
          'default' => 'recent_product'
        ]
      );

        $this->add_control(
            'slugs',
            [
                'label' => esc_html__( 'Categories Slug', 'anymag-core' ),
                'type' => Controls_Manager::TEXTAREA,
                'rows' => 2,
                'default' => '',
                'placeholder' => esc_html__( 'Enter id spearate by comma(,)', 'anymag-core' ),
            ]
        );

        $this->add_control(
            'link',
            [
                'label'       => esc_html__( 'URL', 'anymag-core' ),
                'type'        => Controls_Manager::TEXT,
                'input_type'  => 'url',
                'placeholder' => esc_html__( 'Enter your url button link here', 'anymag-core' ),
            ]
        );

        $this->add_control(
            'btn_text',
            [
                'label'       => esc_html__( 'Button Text', 'anymag-core' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Enter your button text here', 'anymag-core' ),
            ]
        );
        
        $this->add_control(
            'limit',
            [
                'label' => esc_html__( 'Limit', 'anymag-core' ),
                'type' => Controls_Manager::TEXT,
                'input_type' => 'number',
                'placeholder' => esc_html__( 'Enter number products to display', 'anymag-core' ),
                'default' => 4
            ]
        );

        $this->add_control(
            'layout_type',
            [
                'label' => esc_html__( 'Layout', 'anymag-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => array(
                    'grid' => esc_html__('Grid', 'anymag-core'),
                    'carousel' => esc_html__('Carousel', 'anymag-core'),                    
                    'list' => esc_html__('List', 'anymag-core'),
                    'special' => esc_html__('Special', 'anymag-core'),
                ),
                'default' => 'grid'
            ]
        );

        $this->add_control(
            'columns',
            [
                'label' => esc_html__( 'Columns', 'anymag-core' ),
                'type' => Controls_Manager::TEXT,
                'input_type' => 'number',
                'placeholder' => esc_html__( 'Enter your column number here', 'anymag-core' ),
                'default' => 4
            ]
        );

        $this->end_controls_section();
        //END SECTION CONTENT
}

  protected function render() {
        $settings = $this->get_settings();

        extract( $settings );

        ?>
        <div class="widget widget-products <?php echo esc_attr($layout_type); ?>">            
            <?php if ( !empty($title) ): ?>
              <?php  if (get_theme_mod('anymag_side_pattern', true)) {
                $ttlstyle = 'side-pattern';
              } ?>
                <div class="section-title <?php echo $ttlstyle; ?>">
                  <h4><?php echo esc_attr( $block_title ); ?></h4>
                </div>

            <?php endif; ?>
                <div class="woocommerce elementor-products">                
                <?php
                    $slugs = !empty($slugs) ? array_map('trim', explode(',', $slugs)) : array();
                    $product_type = isset($product_type) ? $product_type : 'recent_product';
                    $args = array(
                        'categories' => $slugs,
                        'product_type' => $product_type,
                        'post_per_page' => $limit,
                    );
                    
                    $loop = anymag_get_products( $args );
                
                    wc_get_template( 'layout-products/'.$layout_type.'.php' , array(
                        'loop' => $loop,
                        'columns' => $columns,
                        'rows' => $rows,
                        'product_item' => 'inner',
                    ) );
                ?>
            </div>            
            <?php if ( !empty($link) && !empty($btn_text) ) { ?>
                <div class="widget-link">
                    <a href="<?php echo esc_url($link); ?>" class="btn btn-outline-primary" target="_blank">
                        <span><?php echo wp_kses_post($btn_text); ?></span>
                    </a>
                </div>        
            <?php } ?>            
        </div>
        <?php
    }
}