<?php
namespace Anymag_Framework\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Anymag_Random extends Widget_Base {

	public function get_name() {
		return 'anymag_random';
	}

	public function get_title() {
		return __( 'Anymag Random Posts', 'anymag-core' );
	}

	public function get_icon() {
		return 'eicon-gallery-grid';
	}

	public function get_categories() {
		return [ 'anymagtheme' ];
	}

	public function get_script_depends() {
		return [ 'script-elementor' ];
	}

	protected function _register_controls() {

		$args = '';

		$categories=get_categories($args);
		$cate_array = array();
		$arrayCateAll = array( 'all' => 'All categories ' );
		if ($categories) {
			foreach ( $categories as $cate ) {
				$cate_array[$cate->cat_name] = $cate->slug;
			}
		} else {
			$cate_array["No content Category found"] = 0;
		}

		//SECTION CONTENT
		$this->start_controls_section(
			'section_recent_posts',
			[
				'label' => esc_html__( 'Anymag Random Posts', 'anymag-core' ),
			]
		);
		$this->add_control(
			'block_title',
			[
				'label' => esc_html__( 'Block title', 'anymag-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);
		$this->add_control(
			'category',
			[
				'label' => __( 'Category', 'anymag-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'all',
				'options' => array_merge($arrayCateAll,$cate_array),
			]
		);
		$this->add_control(
			'style',
			[
				'label' => esc_html__( 'Style', 'anymag-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'classic' => esc_html__( 'Classic', 'anymag-core' ),
					'overlay' => esc_html__( 'Overlay', 'anymag-core' ),
				],
				'default' => 'classic',
			]
		);
		$this->add_control(
			'orderby',
			[
				'label' => esc_html__( 'Order by', 'anymag-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'random' => esc_html__( 'Random', 'anymag-core' ),
					'date' => esc_html__( 'Date', 'anymag-core' ),
				],
				'default' => 'random',
			]
		);
		$this->add_control(
			'show_date',
			[
				'label' => __( 'Show Date', 'anymag-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'anymag-core' ),
				'label_off' => __( 'Hide', 'anymag-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$this->add_control(
			'post_ids',
			[
				'label' => __( 'Select Posts', 'anymag-core' ),
				'type' => Controls_Manager::SELECT2,
				'options' => anymag_all_posts(),
				'default' => '',
				'multiple' => true
			]
		);
		$this->add_control(
			'exclude_posts',
			[
				'label' => __( 'Exclude Posts', 'anymag-core' ),
				'type' => Controls_Manager::SELECT2,
				'options' => anymag_all_posts(),
				'default' => '',
				'multiple' => true
			]
		);
		if (get_theme_mod( 'anymag_multiple_issues' )) {
		$this->add_control(
			'rand_tag',
			[
				'label' => esc_html__( 'Tag', 'anymag-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);
	  }
		$this->end_controls_section();
		//END SECTION CONTENT
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		extract(shortcode_atts(array(
	    'block_title' => '',
    	'orderby' => 'random',
    	'order' => 'DESC',
    	'category' => '',
    	'show_date' => 'true',
    	'style' => '',
    	'rand_tag' => '',
    	'post_ids' => '',
    	'exclude_posts' => '',
    	'ignore_sticky_posts' => 'false'
	    ), $settings));

		$exclude_posts = $exclude_posts != '' ? $exclude_posts : array();
		$exclude_posts = implode(',', $exclude_posts);

		$post_ids = $post_ids != '' ? $post_ids : array();
		$post_ids = implode(',', $post_ids);

		if ($category != 'all') {
		 $category = get_term_by( 'name', $category, 'category');
     $category = $category->slug;
    }

    $out = '[random_posts
			title="'.$block_title.'" 
			category="'.$category.'" 
			style="'.$style.'" 
			order="'.$orderby.'" 
			show_date="'.$show_date.'" 
			post_ids="'.$post_ids.'" 
			exclude_posts="'.$exclude_posts.'" 
			tag="'.$rand_tag.'"]';
		echo shortcode_unautop(do_shortcode($out));

	}
}