<?php
namespace Anymag_Framework\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Anymag_Slider extends Widget_Base {

	public function get_name() {
		return 'anymag_slider';
	}

	public function get_title() {
		return __( 'Anymag Slider', 'anymag-core' );
	}

	public function get_icon() {
		return 'eicon-slides';
	}

		public function is_reload_preview_required() {
		return true;
	}

  public function get_categories() {
		return [ 'anymagtheme' ];
	}

		public function __construct($data = [], $args = null) {
		parent::__construct($data, $args);
		wp_enqueue_script('owl-carousel');
		wp_enqueue_style( 'owl-carousel' );
	}

	public function get_script_depends() {
		return [ 'script-elementor' ];
		return [ 'owl-carousel' ];
	}


	public function get_style_depends() {
	 return [ 'owl-carousel' ];
	}

	protected function _register_controls() {

		$args = '';

   	$categories=get_categories($args);
		$cate_array = array();
		$arrayCateAll = array( 'all' => 'All categories ' );
		if ($categories) {
			foreach ( $categories as $cate ) {
				$cate_array[$cate->cat_name] = $cate->slug;
			}
		} else {
			$cate_array["No content Category found"] = 0;
		}

		$this->start_controls_section(
			'section_slider',
			[
				'label' => esc_html__( 'Anymag Post Slider', 'anymag-core' ),
			]
		);
		$this->add_control(
			'block_title',
			[
				'label' => esc_html__( 'Block title', 'anymag-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);
		$this->add_control(
			'feat_posts',
			[
				'label' => esc_html__( 'Featured Posts IDs', 'anymag-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);
		$this->add_control(
			'posts_num',
			[
				'label' => esc_html__( 'Posts Number', 'anymag-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => '5',
			]
		);
		$this->add_control(
			'category',
			[
				'label' => __( 'Category', 'anymag-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'all',
				'options' => array_merge($arrayCateAll,$cate_array),
			]
		);
		$this->add_control(
			'autoplay',
			[
				'label' => __( 'Autoplay', 'anymag-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'On', 'anymag-core' ),
				'label_off' => __( 'Off', 'anymag-core' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
		$this->add_control(
			'show_nav',
			[
				'label' => __( 'Show Navigation', 'anymag-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'anymag-core' ),
				'label_off' => __( 'Hide', 'anymag-core' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
	  $this->add_control(
			'show_cats',
			[
				'label' => __( 'Show Category', 'anymag-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'anymag-core' ),
				'label_off' => __( 'Hide', 'anymag-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
	  $this->add_control(
			'show_author',
			[
				'label' => __( 'Show Author', 'anymag-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'anymag-core' ),
				'label_off' => __( 'Hide', 'anymag-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_avatar',
			[
				'label' => __( 'Show Avatar', 'anymag-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'anymag-core' ),
				'label_off' => __( 'Hide', 'anymag-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_date',
			[
				'label' => __( 'Show Date', 'anymag-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'anymag-core' ),
				'label_off' => __( 'Hide', 'anymag-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$this->add_control(
			'overlay',
			[
				'label' => __( 'Overlay', 'anymag-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'anymag-core' ),
				'label_off' => __( 'Hide', 'anymag-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		if (get_theme_mod( 'anymag_multiple_issues' )) {
		$this->add_control(
			'tag',
			[
				'label' => esc_html__( 'Tag', 'anymag-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);
	  }

		$this->end_controls_section();
	}

	/**
	 * Render icon list widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		wp_enqueue_script('owl-carousel');
		wp_enqueue_style( 'owl-carousel' );

		extract(shortcode_atts(array(
	    'block_title' => '',
    	'autoplay' => 'true',
    	'loop' => 'false',
    	'posts_num' => '5',
    	'orderby' => 'date',
    	'order' => 'DESC',
    	'cat_slug' => '',
    	'category' => '',
    	'show_nav' => 'true',
    	'feat_posts' => '',
    	'overlay' => 'yes',
    	'show_cats' => 'yes',
    	'show_author' => 'yes',
    	'show_avatar' => 'yes',
    	'tag' => '',
    	'show_date' => 'yes'
	    ), $settings));
	    if(!$autoplay){
	    	$autoplay = 'false';
	    }
	    if(!$show_nav){
	    	$show_nav = 'false';
	    }
	    if($feat_posts) {
			  $feat_posts = str_replace(' ', '', $feat_posts);
			  $feat_posts = explode(',', $feat_posts);
      }
	    global $post;

			if ( is_front_page() ) {
				$paged = (get_query_var('page')) ? get_query_var('page') : 1;
			} else {
				$paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
			}

		if($paged == 1) {
    
    $catid='';

		if ($category && $category != 'all') {
		$category = get_term_by( 'name', $category, 'category');
    $category = $category->slug;
			$slug = $category;
			$cat = get_category_by_slug($slug); 
			$catid = $cat->term_id;
		}
 
	  $exclude_post= array();
	  array_push($exclude_post, $post->ID);

		if($feat_posts) {
			$args = array( 
				'showposts' => $posts_num, 
				'post_type' => array('post', 'page'), 
				'post_status'    => 'publish',
				'post__in' => $feat_posts, 
				'orderby' => 'post__in',
				'ignore_sticky_posts' => true 
			);
		} else {
			$args = array(
				'showposts'      => $posts_num, 
				'post_type'      => 'post',
				'order'          => $order,
				'orderby'        => $orderby,
				'tag'            => $tag,
				'post_status'    => 'publish',
				'post__not_in'   => $exclude_post,
				'ignore_sticky_posts' => true,
				'cat' => $catid
			);
	  }
		
		if(!empty($cat_slug))
		$cat_slug = implode(',', $cat_slug);
		if($cat_slug != '' && $cat_slug != 'all'){
			$str = $cat_slug;
			$arr = explode(',', $str);	  
			$args['tax_query'][] = array(
			  'taxonomy'  => 'category',
			  'field'   => 'slug',
			  'terms'   => $arr
			);
		}

    $items = '1';

		static $slider_id = 0;
		$out = '';
		$the_query = new \WP_Query( $args );
		if( $the_query->have_posts() ) {
			$owl_custom = 'jQuery(document).ready(function($){
				"use strict";
				setTimeout(function(){
					var owl = $("#slider-'.++$slider_id.'").owlCarousel(
				    {
				        items: '.$items.',
				        nav: '.$show_nav.',
				        navText : ["<i class=\'fas fa-arrow-left\'></i>","<i class=\'fas fa-arrow-right\'></i>"],
				        autoplay: '.$autoplay.',
				        responsiveClass: true,
				        margin: 1,
				        loop: true,
				        themeClass: "owl-post-slider",';
				    $owl_custom .= '});';
				$owl_custom .= '}, 100);
			});';
			wp_add_inline_script('owl-carousel', $owl_custom);
			
			if( $block_title != ''){

      if (get_theme_mod('anymag_side_pattern', true)) {
         $ttlstyle = 'side-pattern';
      }

				$out .= '<div class="section-title '.$ttlstyle.'"><h3>'.esc_html($block_title).'</h3></div>';
			}

			$out .= '<div id="slider-content"><div class="slider-area">
			<div id="slider-'.$slider_id.'" class="featured-carousel owl-carousel post-slider">';
			static $post_count = 0;
			while ( $the_query->have_posts() ) {
				$the_query->the_post();
				$post_count++;
      if( $the_query->current_post +1 == $the_query->post_count && $the_query->post_count % 2 != 0 ){
        $last = ' last-one';
      } else {
        $last = '';
      }
			$out .= '<div class="slide-item">';
      if($overlay == 'yes'){
			   $out .= '<div class="post-overlay"></div>';
        } 

       if(has_post_thumbnail()) {
          $get_feat_image = wp_get_attachment_image_src( get_post_thumbnail_id($post->ID), 'anymag-slide' );
          $feat_image = $get_feat_image[0];
        } else {
          $feat_image = get_template_directory_uri() . '/assets/img/slider-default.png';
        }
        $out .= '<div class="slide-content" style="background-image:url('.$feat_image.')"><a href="'.esc_url(get_the_permalink()).'" rel="bookmark"></div>';
					$out .= '<div class="slide-text">';
            if($show_cats == 'yes'){
              $out .= '<div class="post-categs-box slider-meta"><div class="categ">'.get_the_category_list(' ').'</div></div>';
            }
            if (get_theme_mod('anymag_hover_style', true) == 'hover-underline') {
            $out .= '<div class="slide-title underline"><h3><a href="'.get_the_permalink().'" title="'.esc_attr(the_title_attribute('echo=0')).'" rel="bookmark">'.esc_attr(get_the_title()).'</a></h3></div>'; }
            else {
            $out .= '<div class="slide-title"><h3><a href="'.get_the_permalink().'" title="'.esc_attr(the_title_attribute('echo=0')).'" rel="bookmark">'.esc_attr(get_the_title()).'</a></h3></div>'; }
            $out .= '<ul class="post-meta">';
              if($show_author == 'yes') {
                if($show_avatar == 'yes') {
                  $out .='<div class="author-avatar">'.get_avatar(get_the_author_meta('ID'),30).'</div>';
                 }
                $out .='<li class="post-author"><span class="author">'.get_the_author_posts_link().'</span></li>'; 
             }
            if( $show_date == 'yes' ){
              $out .= '<li class="list-date"><time datetime="'.esc_attr(date(DATE_W3C)).'">'.get_the_time(get_option('date_format')).'</time></li>';
            }
          $out .= '</ul>';
        $out .= '</div>';
        $out .= '</div>';
			}
			$out .= '</div></div></div>';
		}
	}
		wp_reset_postdata();
		echo $out;

			echo '<script>'.$owl_custom.'</script>';
	}
}
?>