<?php
if ( ! class_exists( 'anymag_latest_posts_widget' ) ) {

 class anymag_latest_posts_widget extends WP_Widget {

	// Widget setup
	
	function __construct() {
		$widget_ops = array( 'description' => __('A widget that displays your latest posts', 'anymag') );
		$control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'anymag_latest_posts_widget' );
		parent::__construct( 'anymag_latest_posts_widget', __('(Anymag) Latest Posts', 'anymag'), $widget_ops, $control_ops );
	}

	// Widget Output
		function widget( $args, $instance ) {
		extract( $args );

		/* Get variables from widget settings */
		$title = apply_filters('widget_title', $instance['title'] );
		$categories = $instance['categories'];
		$number = $instance['number'];

		$query = array('showposts' => $number, 'nopaging' => 0, 'post_status' => 'publish', 'cat' => $categories);
		
		$loop = new WP_Query($query);
		
		echo $before_widget;
		
		if ($loop->have_posts()) :
		
		/* Display the widget title if one was input */
		if ( $title )
			echo $before_title . $title . $after_title;

		?>
			<ul class="latest-posts">
				<?php  while ($loop->have_posts()) : $loop->the_post(); ?>
        <li>
					<div class="latest-posts-item">
						<?php if (  (function_exists('has_post_thumbnail')) && (has_post_thumbnail())  ) : ?>
						  <div class="latest-posts-image">
							  <a href="<?php echo get_permalink() ?>" rel="bookmark"><?php the_post_thumbnail('anymag-small', array('class' => 'side-item-thumb')); ?></a>
						  </div>
						<?php endif; ?>
						<div class="latest-posts-text">
							<h4><a href="<?php echo get_permalink() ?>" rel="bookmark"><?php the_title(); ?></a></h4>
							<span class="latest-posts-meta"><?php the_time( get_option('date_format') ); ?></span>
						</div>
					</div>
				</li>
				<?php endwhile; ?>
			  <?php wp_reset_query(); ?>
			<?php endif;?>
			</ul>
			
		<?php

		echo $after_widget;
	}

	// Update widget settings

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['categories'] = $new_instance['categories'];
		$instance['number'] = strip_tags( $new_instance['number'] );
		return $instance;
	}

	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array( 'title' => __('Latest Posts', 'anymag'), 'number' => 5, 'categories' => '');
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:', 'anymag'); ?></label>
			<input  type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>"  />
		</p>
		
		<!-- Category -->
		<p>
		<label for="<?php echo $this->get_field_id('categories'); ?>">Filter by Category:</label> 
		<select id="<?php echo $this->get_field_id('categories'); ?>" name="<?php echo $this->get_field_name('categories'); ?>" class="widefat categories" style="width:100%;">
			<option value='all' <?php if ('all' == $instance['categories']) echo 'selected="selected"'; ?>>All categories</option>
			<?php $categories = get_categories('hide_empty=0&depth=1&type=post'); ?>
			<?php foreach($categories as $category) { ?>
			<option value='<?php echo $category->term_id; ?>' <?php if ($category->term_id == $instance['categories']) echo 'selected="selected"'; ?>><?php echo $category->cat_name; ?></option>
			<?php } ?>
		</select>
		</p>
		
		<!-- Number of posts -->
		<p>
			<label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e('Number of posts to show:', 'anymag'); ?></label>
			<input  type="text" class="widefat" id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" value="<?php echo $instance['number']; ?>" size="3" />
		</p>
	<?php }
  
  }

  function anymag_latest_posts_widget_init() {
	  register_widget( 'anymag_latest_posts_widget' );
  }
  add_action( 'widgets_init', 'anymag_latest_posts_widget_init' );

}
?>